==> iconify_icons-1.0.0.tar.gz: iconify_icons/src/Form/Settings.php <==
<?php

namespace Drupal\iconify_icons\Form;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Config\TypedConfigManagerInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Link;
use Drupal\Core\Url;
use Drupal\iconify_icons\IconifyServiceInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Admin settings for Iconify Icons.
 *
 * @package Drupal\iconify_icons\Form
 */
class Settings extends ConfigFormBase {

  /**
   * The iconify icons service.
   *
   * @var \Drupal\iconify_icons\IconifyServiceInterface
   */
  protected $iconify;

  /**
   * Constructs a Settings object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The factory for configuration objects.
   * @param \Drupal\Core\Config\TypedConfigManagerInterface $typedConfigManager
   *   The typed config manager.
   * @param \Drupal\iconify_icons\IconifyServiceInterface $iconify
   *   The iconify icons service.
   */
  public function __construct(ConfigFactoryInterface $config_factory, TypedConfigManagerInterface $typedConfigManager, IconifyServiceInterface $iconify) {
    parent::__construct($config_factory, $typedConfigManager);
    $this->iconify = $iconify;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('config.typed'),
      $container->get('iconify_icons.iconify_service')
    );
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['iconify_icons.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'iconify_icons_settings';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('iconify_icons.settings');
    $form = parent::buildForm($form, $form_state);

    $form['ckeditor5'] = [
      '#type' => 'details',
      '#title' => $this->t('CKEditor5 settings'),
      '#open' => TRUE,
    ];

    $form['ckeditor5']['search'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Icon Collections'),
      '#size' => 60,
      '#maxlength' => 128,
      '#placeholder' => $this->t('Filter collections'),
      '#attributes' => [
        'class' => ['iconify-icons-widget-checkboxes-filter'],
      ],
      '#attached' => [
        'library' => ['iconify_icons/default'],
      ],
    ];

    $form['ckeditor5']['collections'] = [
      '#type' => 'checkboxes',
      '#options' => $this->getOptions(),
      '#default_value' => $config->get('collections') ?? [],
      '#description' => $this->t('Select the collections which are going to provide the set of icons. See @collectionIconsLink list.', [
        '@collectionIconsLink' => Link::fromTextAndUrl($this->t('the Iconify icon collections'), Url::fromUri('https://icon-sets.iconify.design/', [
          'attributes' => [
            'target' => '_blank',
          ],
        ]))->toString(),
      ]),
      '#attributes' => [
        'class' => ['iconify-icons-widget-collections'],
      ],
      '#attached' => [
        'library' => ['iconify_icons/default'],
      ],
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $collections = array_filter($form_state->getValue('collections'));
    $this->configFactory->getEditable('iconify_icons.settings')
      ->set('collections', array_combine($collections, $collections))
      ->save();

    parent::submitForm($form, $form_state);
  }

  /**
   * Gets a custom name for an icon collection.
   *
   * This method formats a custom name for the icon collection using its name,
   * category, total number of icons, and a link to view the icons.
   *
   * @param array $collection
   *   An associative array containing the details of the collection.
   * @param string $collection_id
   *   The unique identifier for the collection.
   *
   * @return string
   *   The formatted custom name for the collection.
   */
  protected function getCustomCollectionName(array $collection, string $collection_id): string {
    return sprintf(
      '<strong>%s</strong> - %s (%d) <a href="https://icon-sets.iconify.design/%s" target="_blank">See icons</a>',
      $collection['name'] ?? 'Unknown Name',
      $collection['category'] ?? 'Uncategorized',
      $collection['total'] ?? 0,
      $collection_id
    );
  }

  /**
   * Gets and sorts icon collections.
   *
   * This method fetches the icon collections and sorts them by the 'total'
   * key in descending order. It then generates an array of options where each
   * option is the custom name of the collection.
   *
   * @return array
   *   An associative array of collection IDs and their custom names.
   *
   * @throws \GuzzleHttp\Exception\GuzzleException
   * @throws \JsonException
   */
  protected function getOptions(): array {
    // Fetch and sort collections by 'total' in descending order.
    $collections = $this->iconify->getCollections();
    uasort($collections, fn($a, $b) => $b['total'] <=> $a['total']);

    $options = [];

    foreach ($collections as $collection_id => $collection) {
      $options[$collection_id] = $this->getCustomCollectionName($collection, $collection_id);
    }

    return $options;
  }

}

==> iconify_icons-1.0.5.tar.gz: iconify_icons/src/Form/Settings.php <==
<?php

namespace Drupal\iconify_icons\Form;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Config\TypedConfigManagerInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Link;
use Drupal\Core\Url;
use Drupal\iconify_icons\IconifyServiceInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Admin settings for Iconify Icons.
 *
 * @package Drupal\iconify_icons\Form
 */
class Settings extends ConfigFormBase {

  /**
   * The iconify icons service.
   *
   * @var \Drupal\iconify_icons\IconifyServiceInterface
   */
  protected $iconify;

  /**
   * Constructs a Settings object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The factory for configuration objects.
   * @param \Drupal\Core\Config\TypedConfigManagerInterface $typedConfigManager
   *   The typed config manager.
   * @param \Drupal\iconify_icons\IconifyServiceInterface $iconify
   *   The iconify icons service.
   */
  public function __construct(ConfigFactoryInterface $config_factory, TypedConfigManagerInterface $typedConfigManager, IconifyServiceInterface $iconify) {
    parent::__construct($config_factory, $typedConfigManager);
    $this->iconify = $iconify;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('config.typed'),
      $container->get('iconify_icons.iconify_service')
    );
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['iconify_icons.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'iconify_icons_settings';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('iconify_icons.settings');
    $form = parent::buildForm($form, $form_state);

    $form['ckeditor5'] = [
      '#type' => 'details',
      '#title' => $this->t('CKEditor5 settings'),
      '#open' => TRUE,
    ];

    $form['ckeditor5']['search'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Icon Collections'),
      '#size' => 60,
      '#maxlength' => 128,
      '#placeholder' => $this->t('Filter collections'),
      '#attributes' => [
        'class' => ['iconify-icons-widget-checkboxes-filter'],
      ],
      '#attached' => [
        'library' => ['iconify_icons/default'],
      ],
    ];

    $form['ckeditor5']['collections'] = [
      '#type' => 'checkboxes',
      '#options' => $this->getOptions(),
      '#default_value' => $config->get('collections') ?? [],
      '#description' => $this->t('Select the collections which are going to provide the set of icons. See @collectionIconsLink list. Leave empty to select all.', [
        '@collectionIconsLink' => Link::fromTextAndUrl($this->t('the Iconify icon collections'), Url::fromUri('https://icon-sets.iconify.design/', [
          'attributes' => [
            'target' => '_blank',
          ],
        ]))->toString(),
      ]),
      '#attributes' => [
        'class' => ['iconify-icons-widget-collections'],
      ],
      '#attached' => [
        'library' => ['iconify_icons/default'],
      ],
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $collections = array_filter($form_state->getValue('collections'));
    $this->configFactory->getEditable('iconify_icons.settings')
      ->set('collections', array_combine($collections, $collections))
      ->save();

    parent::submitForm($form, $form_state);
  }

  /**
   * Gets a custom name for an icon collection.
   *
   * This method formats a custom name for the icon collection using its name,
   * category, total number of icons, and a link to view the icons.
   *
   * @param array $collection
   *   An associative array containing the details of the collection.
   * @param string $collection_id
   *   The unique identifier for the collection.
   *
   * @return string
   *   The formatted custom name for the collection.
   */
  protected function getCustomCollectionName(array $collection, string $collection_id): string {
    return sprintf(
      '<strong>%s</strong> - %s (%d) <a href="https://icon-sets.iconify.design/%s" target="_blank">See icons</a>',
      $collection['name'] ?? 'Unknown Name',
      $collection['category'] ?? 'Uncategorized',
      $collection['total'] ?? 0,
      $collection_id
    );
  }

  /**
   * Gets and sorts icon collections.
   *
   * This method fetches the icon collections and sorts them by the 'total'
   * key in descending order. It then generates an array of options where each
   * option is the custom name of the collection.
   *
   * @return array
   *   An associative array of collection IDs and their custom names.
   *
   * @throws \GuzzleHttp\Exception\GuzzleException
   * @throws \JsonException
   */
  protected function getOptions(): array {
    // Fetch and sort collections by 'total' in descending order.
    $collections = $this->iconify->getCollections();
    uasort($collections, fn($a, $b) => $b['total'] <=> $a['total']);

    $options = [];

    foreach ($collections as $collection_id => $collection) {
      $options[$collection_id] = $this->getCustomCollectionName($collection, $collection_id);
    }

    return $options;
  }

}
